@@ -31,25 +31,25 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
-#include "GL/gl.h"
-#include "GL/glx.h"
+#include <stdlib.h>
+#include <GL/gl.h>
+#include <GL/glx.h>
+
 #include "include/forms.h"
 #include "gl/glcanvas.h"
 
-#include <stdlib.h>
-
 typedef struct {
-	FL_FORM   * form;
-	void      * vdata;
-	char      * cdata;
-	long        ldata;
-	FL_OBJECT * canvas;
-	FL_OBJECT * done;
-	FL_OBJECT * menu;
-	FL_OBJECT * butgrp;
+    FL_FORM   * form;
+    void      * vdata;
+    char      * cdata;
+    long        ldata;
+    FL_OBJECT * canvas;
+    FL_OBJECT * done;
+    FL_OBJECT * menu;
+    FL_OBJECT * butgrp;
 } FD_form;
 
 extern FD_form * create_form_form(void);
@@ -67,38 +67,48 @@ static int prim = GL_POLYGON ;
 static
 void draw_cube( void )
 {
-	glColor3f( 1.0, 0.0, 0.0 );
-	glBegin( prim );
-	v3f( 1.0, 1.0, 1.0 );   v3f( 1.0, -1.0, 1.0 );
-	v3f( 1.0, -1.0, -1.0 ); v3f( 1.0, 1.0, -1.0 );
-	glEnd( );
+    glColor3f( 1.0, 0.0, 0.0 );
+    glBegin( prim );
+    v3f( 1.0, 1.0, 1.0 );   v3f( 1.0, -1.0, 1.0 );
+    v3f( 1.0, -1.0, -1.0 ); v3f( 1.0, 1.0, -1.0 );
+    glEnd( );
 
-	glBegin( prim );
-	v3f( -1.0, 1.0, 1.0 );   v3f( -1.0, 1.0, -1.0 );
-	v3f( -1.0, -1.0, -1.0 ); v3f( -1.0, -1.0, 1.0 );
-	glEnd( );
+    glBegin( prim );
+    v3f( -1.0,  1.0,  1.0 );
+    v3f( -1.0,  1.0, -1.0 );
+    v3f( -1.0, -1.0, -1.0 );
+    v3f( -1.0, -1.0,  1.0 );
+    glEnd( );
 
-	glColor3f( 0.0, 1.0, 0.0 );
-	glBegin( prim );
-	v3f(  1.0, 1.0,  1.0 ); v3f(  1.0, 1.0, -1.0 );
-	v3f( -1.0, 1.0, -1.0 ); v3f( -1.0, 1.0,  1.0 );
-	glEnd( );
+    glColor3f( 0.0, 1.0, 0.0 );
+    glBegin( prim );
+    v3f(  1.0,  1.0,  1.0 );
+    v3f(  1.0,  1.0, -1.0 );
+    v3f( -1.0,  1.0, -1.0 );
+    v3f( -1.0,  1.0,  1.0 );
+    glEnd( );
 
-	glBegin( prim );
-	v3f(  1.0, -1.0,  1.0 ); v3f( -1.0, -1.0,  1.0 );
-	v3f( -1.0, -1.0, -1.0 ); v3f(  1.0, -1.0, -1.0 );
-	glEnd( );
+    glBegin( prim );
+    v3f(  1.0, -1.0,  1.0 );
+    v3f( -1.0, -1.0,  1.0 );
+    v3f( -1.0, -1.0, -1.0 );
+    v3f(  1.0, -1.0, -1.0 );
+    glEnd( );
 
-	glColor3f( 0.0, 0.0, 1.0 );
-	glBegin( prim );
-	v3f(  1.0,  1.0,  1.0 ); v3f( -1.0,  1.0,  1.0 );
-	v3f( -1.0, -1.0,  1.0 ); v3f(  1.0, -1.0,  1.0 );
-	glEnd( );
+    glColor3f( 0.0, 0.0, 1.0 );
+    glBegin( prim );
+    v3f(  1.0,  1.0,  1.0 );
+    v3f( -1.0,  1.0,  1.0 );
+    v3f( -1.0, -1.0,  1.0 );
+    v3f(  1.0, -1.0,  1.0 );
+    glEnd( );
 
-	glBegin( prim );
-	v3f(  1.0, 1.0, -1.0 ); v3f(  1.0,-1.0, -1.0 );
-	v3f( -1.0,-1.0, -1.0 ); v3f( -1.0, 1.0, -1.0 );
-	glEnd( );
+    glBegin( prim );
+    v3f(  1.0,  1.0, -1.0 );
+    v3f(  1.0, -1.0, -1.0 );
+    v3f( -1.0, -1.0, -1.0 );
+    v3f( -1.0,  1.0, -1.0 );
+    glEnd( );
 }
 
 
@@ -107,16 +117,17 @@ void draw_cube( void )
 
 int
 idle_cb( XEvent * ev,
-		 void   * data  FL_UNUSED_ARG )
+         void   * data  FL_UNUSED_ARG )
 {
     static GLfloat xrot,
-		           yrot,
-		           zrot;
+                   yrot,
+                   zrot;
 
-    if ( ! ui->form->visible  || ! ui->canvas->visible )
-		return 0;
+    if (    ! fl_form_is_visible( ui->form )
+         || ! fl_object_is_visible( ui->canvas ) )
+        return 0;
 
-    fl_activate_glcanvas(ui->canvas);
+    fl_activate_glcanvas( ui->canvas );
 
     glClear( GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT );
 
@@ -135,9 +146,9 @@ idle_cb( XEvent * ev,
 
     if ( ev )
     {
-		xrot += 10.0;
-		yrot += 7.0;
-		zrot -= 3.0;
+        xrot += 10.0;
+        yrot += 7.0;
+        zrot -= 3.0;
     }
 
     glXSwapBuffers( fl_display, fl_get_canvas_id( ui->canvas ) );
@@ -151,11 +162,11 @@ idle_cb( XEvent * ev,
 
 int
 canvas_expose( FL_OBJECT * ob   FL_UNUSED_ARG,
-			   Window      win  FL_UNUSED_ARG,
-			   int         w,
-			   int         h,
-			   XEvent *    xev  FL_UNUSED_ARG,
-			   void *      ud   FL_UNUSED_ARG )
+               Window      win  FL_UNUSED_ARG,
+               int         w,
+               int         h,
+               XEvent *    xev  FL_UNUSED_ARG,
+               void *      ud   FL_UNUSED_ARG )
 {
     glViewport( 0, 0, ( GLint ) w, ( GLint ) h );
     glClearColor( 0.0, 0.0, 0.0, 0.0 );
@@ -184,15 +195,15 @@ canvas_expose( FL_OBJECT * ob   FL_UNUSED_ARG,
 
 int
 buttonpress_cb( FL_OBJECT * ob   FL_UNUSED_ARG,
-				Window      win  FL_UNUSED_ARG,
-				int         w    FL_UNUSED_ARG,
-				int         h    FL_UNUSED_ARG,
-				XEvent *    xev  FL_UNUSED_ARG,
-				void *      ud   FL_UNUSED_ARG )
+                Window      win  FL_UNUSED_ARG,
+                int         w    FL_UNUSED_ARG,
+                int         h    FL_UNUSED_ARG,
+                XEvent *    xev  FL_UNUSED_ARG,
+                void *      ud   FL_UNUSED_ARG )
 {
-   static int suspended;
+   static int suspended = 0;
 
-   suspended = ( suspended + 1 ) % 2;
+   suspended ^= 1;
    fl_set_idle_callback( suspended ? 0 : idle_cb, 0 );
 
    return 0;
@@ -204,7 +215,7 @@ buttonpress_cb( FL_OBJECT * ob   FL_UNUSED_ARG,
 
 void
 switch_primitive( FL_OBJECT * ob    FL_UNUSED_ARG,
-				  long        data  FL_UNUSED_ARG )
+                  long        data  FL_UNUSED_ARG )
 {
     static int primitive[ ] = { GL_POLYGON, GL_LINE_LOOP };
     static int i ;
@@ -216,22 +227,22 @@ switch_primitive( FL_OBJECT * ob    FL_UNUSED_ARG,
 /* switch single/dblbuffer */
 
 static int sbuf[ ]= { GLX_RGBA,GLX_DEPTH_SIZE, 1,
-					  GLX_RED_SIZE,            1,
-					  GLX_GREEN_SIZE,          1,
-					  GLX_BLUE_SIZE,           1,
-					  None                        };
+                      GLX_RED_SIZE,            1,
+                      GLX_GREEN_SIZE,          1,
+                      GLX_BLUE_SIZE,           1,
+                      None                        };
 
 static int dbuf[ ]= { GLX_RGBA,
-					  GLX_DEPTH_SIZE,
-					  1,
-					  GLX_RED_SIZE,
-					  1,
-					  GLX_GREEN_SIZE,
-					  1,
-					  GLX_BLUE_SIZE,
-					  1,
-					  /* GLX_DOUBLEBUFFER, */
-					  None};
+                      GLX_DEPTH_SIZE,
+                      1,
+                      GLX_RED_SIZE,
+                      1,
+                      GLX_GREEN_SIZE,
+                      1,
+                      GLX_BLUE_SIZE,
+                      1,
+                      /* GLX_DOUBLEBUFFER, */
+                      None};
 
 
 /***************************************
@@ -239,7 +250,7 @@ static int dbuf[ ]= { GLX_RGBA,
 
 void
 buffer_cb( FL_OBJECT * ob,
-		   long        data  FL_UNUSED_ARG )
+           long        data  FL_UNUSED_ARG )
 {
     static int is_double = 1;
     FD_form *fdui = ob->form->fdui;
@@ -255,7 +266,7 @@ buffer_cb( FL_OBJECT * ob,
 
 void
 menu_cb( FL_OBJECT * ob    FL_UNUSED_ARG,
-		 long        data  FL_UNUSED_ARG )
+         long        data  FL_UNUSED_ARG )
 {
 }
 
@@ -264,12 +275,9 @@ menu_cb( FL_OBJECT * ob    FL_UNUSED_ARG,
  ***************************************/
 
 int main( int    argc,
-		  char * argv[ ] )
+          char * argv[ ] )
 {
-
-   FL_OBJECT *ob;
-
-   fl_initialize( &argc, argv, "FormDemo", 0, 0 );
+   fl_initialize( &argc, argv, "FormDemo", NULL, 0 );
    ui = create_form_form( );
 
    /* fill-in form initialization code */
@@ -286,9 +294,9 @@ int main( int    argc,
 //   fl_set_form_minsize( ui->form, 340, 280 );
 
    fl_show_form( ui->form, FL_PLACE_CENTER | FL_FREE_SIZE, FL_FULLBORDER,
-				 "OpenGL Canvas");
+                 "OpenGL Canvas");
 
-   while( ( ob = fl_do_forms( ) ) != ui->done )
+   while ( fl_do_forms( ) != ui->done )
        /* empty */ ;
 
    fl_finish( );
@@ -301,12 +309,12 @@ int main( int    argc,
 
 static void
 hide_it( FL_OBJECT * ob,
-		 long        data  FL_UNUSED_ARG )
+         long        data  FL_UNUSED_ARG )
 {
-    if( ui->canvas->visible )
+    if ( fl_object_is_visible( ui->canvas ) )
     {
-		fl_hide_object( ui->canvas );
-		fl_set_object_label( ob,"Show" );
+        fl_hide_object( ui->canvas );
+        fl_set_object_label( ob,"Show" );
     }
     else
     {
@@ -321,69 +329,74 @@ hide_it( FL_OBJECT * ob,
 
 static void
 reshow( FL_OBJECT * ob,
-		long        data  FL_UNUSED_ARG )
+        long        data  FL_UNUSED_ARG )
 {
-	fl_hide_form( ob->form );
-	fl_show_form( ui->form, FL_PLACE_CENTER | FL_FREE_SIZE, FL_FULLBORDER,
-				  "OpenGL Canvas" );
+    fl_hide_form( ob->form );
+    fl_show_form( ui->form, FL_PLACE_CENTER | FL_FREE_SIZE, FL_FULLBORDER,
+                  "OpenGL Canvas" );
 }
 
 
-#include <stdlib.h>
-
-
 /***************************************
  ***************************************/
 
 FD_form *
 create_form_form( void )
 {
-	FL_OBJECT *obj;
-	FD_form *fdui = fl_calloc( 1, sizeof *fdui);
+    FL_OBJECT *obj;
+    FD_form *fdui = fl_calloc( 1, sizeof *fdui);
 
-	fdui->form = fl_bgn_form( FL_NO_BOX, 340, 280 );
+    fdui->form = fl_bgn_form( FL_NO_BOX, 340, 280 );
 
-	obj = fl_add_box( FL_UP_BOX, 0, 0, 340, 280, "" );
+    fl_add_box( FL_UP_BOX, 0, 0, 340, 280, "" );
 
-	fdui->canvas = obj = fl_add_glcanvas( FL_NORMAL_CANVAS, 20, 45, 225, 215,
-										  "" );
+    fdui->canvas = obj = fl_add_glcanvas( FL_NORMAL_CANVAS, 20, 45, 225, 215,
+                                          "" );
     fl_set_object_gravity( obj, FL_NorthWest, FL_SouthEast );
 
-	fdui->done = obj = fl_add_button( FL_NORMAL_BUTTON, 255, 230, 70, 30,
-									  "Done");
+    fdui->done = obj = fl_add_button( FL_NORMAL_BUTTON, 255, 230, 70, 30,
+                                      "Done");
     fl_set_button_shortcut( obj, "Dd#d", 1 );
     fl_set_object_gravity( obj, FL_SouthEast, FL_SouthEast );
 
-	fdui->menu = obj = fl_add_menu( FL_PULLDOWN_MENU, 20, 15, 54, 20,
-									"Canvas" );
+    fdui->menu = obj = fl_add_menu( FL_PULLDOWN_MENU, 20, 15, 54, 20,
+                                    "Canvas" );
     fl_set_object_shortcut( obj, "#CcC", 1 );
     fl_set_object_boxtype( obj, FL_FLAT_BOX );
     fl_set_object_lstyle( obj, FL_BOLD_STYLE );
     fl_set_object_gravity( obj, FL_NorthWest, FL_NorthWest );
     fl_set_object_callback( obj, menu_cb, 0 );
 
-	fdui->butgrp = fl_bgn_group( );
+    fdui->butgrp = fl_bgn_group( );
 
-	obj = fl_add_button( FL_NORMAL_BUTTON, 255, 45, 70, 30, "Poly/Line" );
+    obj = fl_add_button( FL_NORMAL_BUTTON, 255, 45, 70, 30, "Poly/Line" );
     fl_set_object_gravity( obj, FL_NorthEast, FL_NorthEast );
     fl_set_object_callback( obj, switch_primitive, 0 );
 
-	obj = fl_add_button( FL_NORMAL_BUTTON, 255, 75, 70, 30, "Hide" );
+    obj = fl_add_button( FL_NORMAL_BUTTON, 255, 75, 70, 30, "Hide" );
     fl_set_button_shortcut( obj, "#HhH", 1 );
     fl_set_object_callback( obj,hide_it, 0 );
 
-	obj = fl_add_button( FL_NORMAL_BUTTON, 255, 105, 70, 30, "ReShow" );
+    obj = fl_add_button( FL_NORMAL_BUTTON, 255, 105, 70, 30, "ReShow" );
     fl_set_button_shortcut( obj, "#RRr", 1 );
     fl_set_object_callback( obj, reshow, 0 );
 
-	obj = fl_add_button( FL_NORMAL_BUTTON, 255, 135, 70, 30, "Single" );
+    obj = fl_add_button( FL_NORMAL_BUTTON, 255, 135, 70, 30, "Single" );
     fl_set_object_callback( obj, buffer_cb, 0 );
 
-	fl_end_group( );
+    fl_end_group( );
 
-	fl_end_form( );
+    fl_end_form( );
 
-	fdui->form->fdui = fdui;
+    fdui->form->fdui = fdui;
 
-	return fdui;
+    return fdui;
 }
+
+
+/*
+ * Local variables:
+ * tab-width: 4
+ * indent-tabs-mode: nil
+ * End:
+ */
