@@ -99,7 +99,7 @@ int
 main( int    argc,
       char * argv[ ] )
 {
-    fl_initialize( &argc, argv, "FormDemo", 0, 0 );
+    fl_initialize( &argc, argv, "FormDemo", NULL, 0 );
     makeform( );
 
     fl_show_form( form, FL_PLACE_MOUSE, FL_TRANSIENT, "A Form" );
