@@ -1,22 +1,18 @@
 /*
- *
  *  This file is part of the XForms library package.
  *
- * XForms is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Lesser General Public License as
- * published by the Free Software Foundation; either version 2.1, or
- * (at your option) any later version.
+ *  XForms is free software; you can redistribute it and/or modify it
+ *  under the terms of the GNU Lesser General Public License as
+ *  published by the Free Software Foundation; either version 2.1, or
+ *  (at your option) any later version.
  *
- * XForms is distributed in the hope that it will be useful, but
- * WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with XForms; see the file COPYING.  If not, write to
- * the Free Software Foundation, 59 Temple Place - Suite 330, Boston,
- * MA 02111-1307, USA.
+ *  XForms is distributed in the hope that it will be useful, but
+ *  WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Lesser General Public License for more details.
  *
+ *  You should have received a copy of the GNU Lesser General Public License
+ *  along with XForms.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 
@@ -26,18 +22,12 @@
  *  This file is part of the XForms library package.
  *  Copyright (c) 1996-2002  T.C. Zhao
  *  All rights reserved.
- *.
  *
  *  Manage application windows
- *
  */
 
-#if defined F_ID || defined DEBUG 
-char *fl_id_evt = "$Id: appwin.c,v 1.13 2008/11/22 18:44:54 jtt Exp $";
-#endif
-
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "include/forms.h"
@@ -53,7 +43,7 @@ char *fl_id_evt = "$Id: appwin.c,v 1.13 2008/11/22 18:44:54 jtt Exp $";
 
 static int
 handle_mapping_notify( XEvent * xev,
-					   void   * user_data  FL_UNUSED_ARG )
+                       void   * user_data  FL_UNUSED_ARG )
 {
     XRefreshKeyboardMapping( ( XMappingEvent * ) xev );
     return 0;
@@ -67,25 +57,25 @@ static void
 remove_app_win( FLI_WIN * appwin )
 {
 #if FL_DEBUG >= ML_DEBUG
-    M_info( "remove_app_win", "deleting 0x%lx", appwin->win );
+    M_info( "remove_app_win", "deleting window %ld", appwin->win );
 #endif
 
     if ( fli_app_win == appwin )
-		fli_app_win = appwin->next;
+        fli_app_win = appwin->next;
     else
     {
-		FLI_WIN *fwin = fli_app_win;
+        FLI_WIN *fwin = fli_app_win;
 
-		while ( fwin && fwin->next != appwin )
-			fwin = fwin->next;
+        while ( fwin && fwin->next != appwin )
+            fwin = fwin->next;
 
-		if ( fwin )
-			fwin->next = fwin->next->next;
-		else
-		{
-			M_err( "remove_app_win", "Invalid argument" );
-			return;
-		}
+        if ( fwin )
+            fwin->next = fwin->next->next;
+        else
+        {
+            M_err( "remove_app_win", "Invalid argument" );
+            return;
+        }
     }
 
     fl_free( appwin );
@@ -100,47 +90,47 @@ static FLI_WIN *
 get_fl_win_struct( Window win )
 {
     FLI_WIN *fwin = fli_app_win,
-		    *lwin = fli_app_win;
-	size_t i;
+            *lwin = fli_app_win;
+    size_t i;
 
     for ( ; fwin && fwin->win != win; lwin = fwin, fwin = fwin->next )
-		/* empty */ ;
+        /* empty */ ;
 
-	/* If we found it we're done */
+    /* If we found it we're done */
 
     if ( fwin )
-		return fwin;
+        return fwin;
+
+    /* Otherwise create a new structure and append it to the end */
 
 #if FL_DEBUG >= ML_DEBUG
-	M_info( "get_fl_win_struct", "Creating FLI_WIN struct for 0x%lx", win );
+    M_info( "get_fl_win_struct", "Creating FLI_WIN struct for %ld", win );
 #endif
 
-	/* Otherwise create a new structure and append it to the end */
+    if ( ( fwin = fl_malloc( sizeof *fwin ) ) == NULL )
+        return NULL;
 
-	if ( ( fwin = fl_malloc( sizeof *fwin ) ) == NULL )
-		return NULL;
+    fwin->next = NULL;
+    fwin->win = win;
+    fwin->pre_emptive = NULL;
+    fwin->pre_emptive_data = NULL;
+    for ( i = 0; i < LASTEvent; i++ )
+    {
+        fwin->callback[  i ] = NULL;
+        fwin->user_data[ i ] = NULL;
+    }
 
-	fwin->next = NULL;
-	fwin->win = win;
-	fwin->pre_emptive = NULL;
-	fwin->pre_emptive_data = NULL;
-	for ( i = 0; i < LASTEvent; i++ )
-	{
-		fwin->callback[ i ] = NULL;
-		fwin->user_data[ i ] = NULL;
-	}
+    /* Default handlers */
 
-	/* Default handlers */
+    fwin->callback[ MappingNotify ] = handle_mapping_notify;
 
-	fwin->callback[ MappingNotify ] = handle_mapping_notify;
+    fwin->default_callback = NULL;
+    fwin->mask = 0;
 
-	fwin->default_callback = NULL;
-	fwin->mask = 0;
-
-	if ( ! fli_app_win )
-		fli_app_win = fwin;
-	else
-		lwin->next = fwin;
+    if ( ! fli_app_win )
+        fli_app_win = fwin;
+    else
+        lwin->next = fwin;
 
     return fwin;
 }
@@ -151,20 +141,21 @@ get_fl_win_struct( Window win )
 
 FL_APPEVENT_CB
 fli_set_preemptive_callback( Window           win,
-							 FL_APPEVENT_CB   pcb,
-							 void           * data )
+                             FL_APPEVENT_CB   pcb,
+                             void           * data )
 {
     FLI_WIN *fwin;
     FL_APPEVENT_CB old = NULL;
 
     if ( ! ( fwin = get_fl_win_struct( win ) ) )
-	{
+    {
         M_err( "fli_set_preemptive_callback", "Memory allocation failure" );
-		return NULL;
-	}
+        return NULL;
+    }
 
     old = fwin->pre_emptive;
-    fwin->pre_emptive = pcb;
+
+    fwin->pre_emptive      = pcb;
     fwin->pre_emptive_data = data;
 
     return old;
@@ -177,38 +168,38 @@ fli_set_preemptive_callback( Window           win,
 
 FL_APPEVENT_CB
 fl_add_event_callback( Window           win,
-					   int              ev,
-					   FL_APPEVENT_CB   wincb,
-					   void *           user_data )
+                       int              ev,
+                       FL_APPEVENT_CB   wincb,
+                       void *           user_data )
 {
     FLI_WIN *fwin;
     int i,
-		nev;
+        nev;
     FL_APPEVENT_CB old = NULL;
 
     if ( ev < 0 || ev >= LASTEvent )
-		return NULL;
+        return NULL;
 
     if ( ! ( fwin = get_fl_win_struct( win ) ) )
-	{
+    {
         M_err( "fl_add_event_callback", "Memory allocation failure" );
-		return NULL;
-	}
+        return NULL;
+    }
 
     /* ev < KeyPress means all events */
 
     nev = ev;
     if ( ev < KeyPress )
     {
-		ev = KeyPress;
-		nev = LASTEvent - 1;
+        ev = KeyPress;
+        nev = LASTEvent - 1;
     }
 
     for ( i = ev; i <= nev; i++ )
     {
-		old = fwin->callback[ i ];
-		fwin->callback[ i ] = wincb;
-		fwin->user_data[ i ] = user_data;
+        old = fwin->callback[ i ];
+        fwin->callback[ i ] = wincb;
+        fwin->user_data[ i ] = user_data;
     }
 
     return old;
@@ -216,33 +207,33 @@ fl_add_event_callback( Window           win,
 
 
 /***************************************
- * Removes one or all event callbacks for a window. May be
- * called with for a window for which no event callbacks
- * have been set, so handle also that case gracefully.
+ * Removes one or all event callbacks for a window. Might be
+ * called for a window for which no event callbacks have been
+ * set, so handle also that case gracefully.
  ***************************************/
 
 void
 fl_remove_event_callback( Window win,
-						  int    ev )
+                          int    ev )
 {
     FLI_WIN *fwin = fli_app_win;
 
     if ( ev < 0 || ev >= LASTEvent )
-		return;
+        return;
 
-	while ( fwin && fwin->win != win )
-		fwin = fwin->next;
+    while ( fwin && fwin->win != win )
+        fwin = fwin->next;
 
     if ( ! fwin )
-		return;
+        return;
 
     if ( ev >= KeyPress )
     {
-		fwin->callback[ ev ] = NULL;
-		fwin->user_data[ ev ] = NULL;
+        fwin->callback[ ev ] = NULL;
+        fwin->user_data[ ev ] = NULL;
     }
     else                         /* ev < KeyPress means all events */
-		remove_app_win( fwin );
+        remove_app_win( fwin );
 }
 
 
@@ -272,11 +263,11 @@ static EMS ems[ ] =
     { KeyPress,         KeyPressMask },
     { KeyRelease,       KeyReleaseMask} ,
     { ButtonPress,        ButtonPressMask
-	                 /* | OwnerGrabButtonMask */ },
+                     /* | OwnerGrabButtonMask */ },
     { ButtonRelease,      ButtonReleaseMask
                      /* | OwnerGrabButtonMask */ },
-	{ MotionNotify,       PointerMotionMask
-	                    | ButtonMotionMask
+    { MotionNotify,       PointerMotionMask
+                        | ButtonMotionMask
                         | PointerMotionHintMask },
     { FocusIn,          FocusChangeMask },
     { FocusOut,         FocusChangeMask },
@@ -302,11 +293,11 @@ unsigned long
 fli_xevent_to_mask( int event )
 {
     EMS *em = ems,
-		*eme = ems + sizeof ems / sizeof *ems;
+        *eme = ems + sizeof ems / sizeof *ems;
 
     for ( ; em < eme; em++ )
-		if ( em->event == event )
-			return em->mask;
+        if ( em->event == event )
+            return em->mask;
 
     return 0;
 }
@@ -323,19 +314,19 @@ fl_activate_event_callbacks( Window win )
     unsigned long mask;
 
     while ( fwin && fwin->win != win )
-		fwin = fwin->next;
+        fwin = fwin->next;
 
     if ( ! fwin )
     {
-		M_err( "fl_activate_event_callbacks", "Unknown window 0x%lx", win );
-		return;
+        M_err( "fl_activate_event_callbacks", "Unknown window %ld", win );
+        return;
     }
 
     /* Solicit all registered events */
 
     for ( mask = i = 0; i < LASTEvent; i++ )
-		if ( fwin->callback[ i ] )
-			mask |= fli_xevent_to_mask( i );
+        if ( fwin->callback[ i ] )
+            mask |= fli_xevent_to_mask( i );
 
     XSelectInput( flx->display, win, mask );
 }
@@ -350,12 +341,21 @@ fl_winclose( Window win )
     XEvent xev;
 
     XUnmapWindow( flx->display, win );
+    fl_winset( None );
     XDestroyWindow( flx->display, win );
 
     XSync( flx->display, 0 );
 
     while ( XCheckWindowEvent( flx->display, win, AllEventsMask, &xev ) )
-		fli_xevent_name( "Eaten", &xev );
+        fli_xevent_name( "Eaten", &xev );
 
     fl_remove_event_callback( win, 0 );
 }
+
+
+/*
+ * Local variables:
+ * tab-width: 4
+ * indent-tabs-mode: nil
+ * End:
+ */
