@@ -24,15 +24,15 @@
 /* Type is already defined in Basic.h */
 
 FL_EXPORT FL_OBJECT * fl_create_box( int          type,
-                                     FL_Coord     x,
-                                     FL_Coord     y,
-                                     FL_Coord     w,
-                                     FL_Coord     h,
+                                     FL_COORD     x,
+                                     FL_COORD     y,
+                                     FL_COORD     w,
+                                     FL_COORD     h,
                                      const char * label );
 
 FL_EXPORT FL_OBJECT * fl_add_box( int          type,
-                                  FL_Coord     x,
-                                  FL_Coord     y,
-                                  FL_Coord     w,
-                                  FL_Coord     h,
+                                  FL_COORD     x,
+                                  FL_COORD     y,
+                                  FL_COORD     w,
+                                  FL_COORD     h,
                                   const char * label );
