@@ -70,31 +70,31 @@ typedef enum {
 /***** Routines *****/
 
 FL_EXPORT FL_OBJECT * fl_create_slider( int          type,
-                                        FL_Coord     x,
-                                        FL_Coord     y,
-                                        FL_Coord     w,
-                                        FL_Coord     h,
+                                        FL_COORD     x,
+                                        FL_COORD     y,
+                                        FL_COORD     w,
+                                        FL_COORD     h,
                                         const char * label );
 
 FL_EXPORT FL_OBJECT * fl_add_slider( int          type,
-                                     FL_Coord     x,
-                                     FL_Coord     y,
-                                     FL_Coord     w,
-                                     FL_Coord     h,
+                                     FL_COORD     x,
+                                     FL_COORD     y,
+                                     FL_COORD     w,
+                                     FL_COORD     h,
                                      const char * label );
 
 FL_EXPORT FL_OBJECT * fl_create_valslider( int          type,
-                                           FL_Coord     x,
-                                           FL_Coord     y,
-                                           FL_Coord     w,
-                                           FL_Coord     h,
+                                           FL_COORD     x,
+                                           FL_COORD     y,
+                                           FL_COORD     w,
+                                           FL_COORD     h,
                                            const char * label );
 
 FL_EXPORT FL_OBJECT * fl_add_valslider( int          type,
-                                        FL_Coord     x,
-                                        FL_Coord     y,
-                                        FL_Coord     w,
-                                        FL_Coord     h,
+                                        FL_COORD     x,
+                                        FL_COORD     y,
+                                        FL_COORD     w,
+                                        FL_COORD     h,
                                         const char * label );
 
 FL_EXPORT void fl_set_slider_value( FL_OBJECT * ob,
