@@ -229,9 +229,9 @@ do_menu( FL_OBJECT *ob )
 static int
 handle_menu( FL_OBJECT * ob,
              int         event,
-             FL_Coord    mx   FL_UNUSED_ARG,
-             FL_Coord    my   FL_UNUSED_ARG,
-             FL_Char     key  FL_UNUSED_ARG,
+             FL_COORD    mx   FL_UNUSED_ARG,
+             FL_COORD    my   FL_UNUSED_ARG,
+             FL_VAL      key  FL_UNUSED_ARG,
              void      * ev   FL_UNUSED_ARG )
 {
     FLI_MENU_SPEC *sp = ob->spec;
@@ -352,10 +352,10 @@ handle_menu( FL_OBJECT * ob,
 
 FL_OBJECT *
 fl_create_menu( int          type,
-                FL_Coord     x,
-                FL_Coord     y,
-                FL_Coord     w,
-                FL_Coord     h,
+                FL_COORD     x,
+                FL_COORD     y,
+                FL_COORD     w,
+                FL_COORD     h,
                 const char * label )
 {
     FL_OBJECT *obj;
@@ -390,10 +390,10 @@ fl_create_menu( int          type,
 
 FL_OBJECT *
 fl_add_menu( int          type,
-             FL_Coord     x,
-             FL_Coord     y,
-             FL_Coord     w,
-             FL_Coord     h,
+             FL_COORD     x,
+             FL_COORD     y,
+             FL_COORD     w,
+             FL_COORD     h,
              const char * label )
 {
     FL_OBJECT *ob;
