@@ -31,8 +31,8 @@
 
 #include "include/forms.h"
 #include "flinternal.h"
-#include <string.h>
 #include "private/flvasprintf.h"
+#include <ctype.h>
 
 
 #define TRANSLATE_Y( obj, form )    ( form->h - obj->h - obj->y )
@@ -45,27 +45,17 @@ extern FL_OBJECT * fli_handled_parent;     /* defined in  events.c */
 static void redraw( FL_FORM *,
                     int );
 static void lose_focus( FL_OBJECT * );
-static void get_object_rect( FL_OBJECT *,
-                             XRectangle *,
-                             int );
-static XRectangle * get_label_rect( FL_OBJECT  * obj,
-                                    XRectangle * rect );
-static int objects_intersect( FL_OBJECT *,
-                              FL_OBJECT * );
+static XRectangle * get_label_rect( const FL_OBJECT  * obj,
+                                    XRectangle       * rect );
+static int objects_intersect( const FL_OBJECT *,
+                              const FL_OBJECT * );
 static void mark_object_for_redraw( FL_OBJECT * );
-static int object_is_under( FL_OBJECT * );
+static int object_is_under( const FL_OBJECT * );
 static void checked_hide_tooltip( FL_OBJECT *,
                                   XEvent    * );
-static int prep_recalc( FL_FORM   * form,
-                         FL_OBJECT * start_obj );
-static void finish_recalc( FL_FORM   * form,
-                           FL_OBJECT * start_obj );
 
 static FL_OBJECT *refocus;
 
-static void **tmp_vdata = NULL;
-static FL_RECT *tmp_rects = NULL;
-
 #define IS_BUTTON_CLASS( i )   (    i == FL_BUTTON           \
                                  || i == FL_ROUNDBUTTON      \
                                  || i == FL_ROUND3DBUTTON    \
@@ -75,7 +65,7 @@ static FL_RECT *tmp_rects = NULL;
                                  || i == FL_PIXMAPBUTTON )
 
 
-/* Macro for checking of a FL_FORM pointer points to a form that should
+/* Macro for checking if a FL_FORM pointer points to a form that should
    be actually drawn to */
 
 #define FORM_IS_UPDATABLE( form ) (    form                             \
@@ -83,9 +73,9 @@ static FL_RECT *tmp_rects = NULL;
                                     && ( form )->frozen == 0 )
 
 
-/* Macro for checking if a label is to be consider to be "outside" of its
-   object for redrawing purposes. When a label is outside its object and
-   we change the position or size of the object or the text, style or
+/* Macro for checking if a label is to be considered to be "outside" of its
+   object for redrawing purposes. When a label is outside of its object and
+   we change the position or size of the object, the text, or style or
    font size of the label then other objects under the label also need
    to be redrawn. In priciple calling fl_is_outside_lalign() should do
    the job but there are some semi-transparent objects which we need to
@@ -119,18 +109,18 @@ bg_object( FL_FORM * form )
 
 
 /***************************************
- * Creates an object - NOT FOR USE BY USERS OF THE LIBRARY!
+ * Creates an object - NOT MEANT FOR USE BY USERS OF THE LIBRARY!
  ***************************************/
 
 FL_OBJECT *
-fl_make_object( int            objclass,
-                int            type,
-                FL_Coord       x,
-                FL_Coord       y,
-                FL_Coord       w,
-                FL_Coord       h,
-                const char   * label,
-                FL_HANDLEPTR   handle )
+fl_make_object( int             objclass,
+                int             type,
+                FL_COORD        x,
+                FL_COORD        y,
+                FL_COORD        w,
+                FL_COORD        h,
+                const char    * label,
+                FL_HANDLE_PTR   handle )
 {
     FL_OBJECT *obj;
 #ifdef FL_WIN32
@@ -143,6 +133,8 @@ fl_make_object( int            objclass,
 
     obj->objclass  = objclass;
     obj->type      = type;
+    obj->lsize     = FL_DEFAULT_SIZE;
+    obj->lstyle    = FL_NORMAL_STYLE;
     obj->resize    = FL_RESIZE_ALL;
     obj->nwgravity = obj->segravity = FL_NoGravity;
     obj->boxtype   = FL_NO_BOX;
@@ -164,19 +156,19 @@ fl_make_object( int            objclass,
             break;
 
         case FL_COORD_MM :
-            fli_scale_object( obj, fli_dpi / 25.4, fli_dpi / 25.4 );
+            fli_scale_object( obj, fl_dpi / 25.4, fl_dpi / 25.4 );
             break;
 
         case FL_COORD_POINT :
-            fli_scale_object( obj, fli_dpi / 72.0, fli_dpi / 72.0 );
+            fli_scale_object( obj, fl_dpi / 72.0, fl_dpi / 72.0 );
             break;
 
         case FL_COORD_centiPOINT :
-            fli_scale_object( obj, fli_dpi / 7200.0, fli_dpi / 7200.0 );
+            fli_scale_object( obj, fl_dpi / 7200.0, fl_dpi / 7200.0 );
             break;
 
         case FL_COORD_centiMM :
-            fli_scale_object( obj, fli_dpi / 2540.0, fli_dpi / 2540.0 );
+            fli_scale_object( obj, fl_dpi / 2540.0, fl_dpi / 2540.0 );
             break;
 
         default:
@@ -216,7 +208,7 @@ fl_make_object( int            objclass,
         obj->lsize = FL_DEFAULT_SIZE;
 
     obj->lstyle             = FL_NORMAL_STYLE;
-    obj->shortcut           = fl_calloc( 1, sizeof( long ) );
+    obj->shortcut           = fl_calloc( 1, sizeof *obj->shortcut );
     *obj->shortcut          = 0;
     obj->active             = 1;
     obj->visible            = FL_VISIBLE;
@@ -230,9 +222,13 @@ fl_make_object( int            objclass,
     obj->nc                 = NULL;
     obj->group_id           = 0;
     obj->set_return         = NULL;
+    obj->set_react_to       = NULL;
     obj->how_return         = FL_RETURN_ALWAYS;
     obj->returned           = 0;
     obj->is_under           = 0;
+    obj->react_to           =   FL_MBUTTON1_BIT | FL_MBUTTON2_BIT
+                              | FL_MBUTTON3_BIT | FL_MBUTTON4_BIT
+                              | FL_MBUTTON5_BIT;
 
     return obj;
 }
@@ -296,6 +292,8 @@ fl_add_object( FL_FORM   * form,
     obj->ft2 = obj->y  + obj->h;
     obj->fb2 = form->h - obj->ft2;
 
+    fli_calc_object_bbox( obj );
+
     /* If adding to a group, set objects group ID, then find the end of the
        group or the end of the object list of this form */
 
@@ -308,7 +306,7 @@ fl_add_object( FL_FORM   * form,
         while ( end && end->objclass != FL_END_GROUP )
             end = end->next;
 
-        /* If 'end' exists must've opened the group with fl_addto_group */
+        /* If 'end' exists must have opened the group with fl_addto_group */
 
         if ( end )
         {
@@ -1090,6 +1088,8 @@ fl_set_object_label( FL_OBJECT  * obj,
     obj->label = fl_realloc( obj->label, strlen( label ) + 1 );
     strcpy( obj->label, label );
 
+    fli_calc_object_bbox( obj );
+
     if ( need_show )
         fl_show_object( obj );
     else if ( obj->visible )
@@ -1214,6 +1214,12 @@ fl_set_object_lsize( FL_OBJECT * obj,
         return;
     }
 
+    if ( lsize < 1 )
+    {
+        M_err( "fl_set_object_lsize", "Invalid label size" );
+        return;
+    }
+
     if ( obj->objclass != FL_BEGIN_GROUP && obj->lsize == lsize )
         return;
 
@@ -1228,6 +1234,7 @@ fl_set_object_lsize( FL_OBJECT * obj,
     }
 
     obj->lsize = lsize;
+    fli_calc_object_bbox( obj );
     fli_handle_object( obj, FL_ATTRIB, 0, 0, 0, NULL, 0 );
 
     if ( obj->objclass == FL_TABFOLDER )
@@ -1237,6 +1244,7 @@ fl_set_object_lsize( FL_OBJECT * obj,
         for ( o = obj->next; o && o->objclass != FL_END_GROUP; o = o->next )
         {
             obj->lsize = lsize;
+            fli_calc_object_bbox( o );
             fli_handle_object( o, FL_ATTRIB, 0, 0, 0, NULL, 0 );
         }
 
@@ -1294,6 +1302,7 @@ fl_set_object_lstyle( FL_OBJECT * obj,
     }
 
     obj->lstyle = lstyle;
+    fli_calc_object_bbox( obj );
     fli_handle_object( obj, FL_ATTRIB, 0, 0, 0, NULL, 0 );
 
     if ( obj->objclass == FL_TABFOLDER )
@@ -1303,6 +1312,7 @@ fl_set_object_lstyle( FL_OBJECT * obj,
         for ( o = obj->next; o && o->objclass != FL_END_GROUP; o = o->next )
         {
             obj->lstyle = lstyle;
+            fli_calc_object_bbox( o );
             fli_handle_object( o, FL_ATTRIB, 0, 0, 0, NULL, 0 );
         }
 
@@ -1362,6 +1372,7 @@ fl_set_object_lalign( FL_OBJECT * obj,
     }
 
     obj->align = align;
+    fli_calc_object_bbox( obj );
     fli_handle_object( obj, FL_ATTRIB, 0, 0, 0, NULL, 0 );
 
     if ( obj->objclass == FL_TABFOLDER )
@@ -1580,8 +1591,6 @@ void
 fli_hide_and_get_region( FL_OBJECT * obj,
                          Region    * reg )
 {
-    FL_RECT xrect;  
-
 #ifdef DELAYED_ACTION
     /* Remove all entries for the object from the object queue */
 
@@ -1611,15 +1620,13 @@ fli_hide_and_get_region( FL_OBJECT * obj,
     if ( obj == fli_int.mouseobj )
         fli_int.mouseobj = NULL;
 
-    /* Get the area the object covers and add that to the region passed 
+    /* Add the area covered by the object and add it to the region passed 
        to the function */
 
     if ( obj->objclass == FL_CANVAS || obj->objclass == FL_GLCANVAS )
         fli_hide_canvas( obj );
 
-    get_object_rect( obj, &xrect, 0 );
-
-    XUnionRectWithRegion( &xrect, *reg, *reg );
+    XUnionRectWithRegion( &obj->bbox, *reg, *reg );
 
     /* Mark it as invisible (must be last, fli_hide_canvas() tests for
        visibility and doesn't do anything if already marked as invisible) */
@@ -1680,6 +1687,8 @@ fl_hide_object( FL_OBJECT * obj )
         fli_hide_and_get_region( obj, &reg );
     }
 
+    fli_recalc_intersections( obj->form );
+
     /* No redraw is needed if the object has no form or the form isn't shown
        or is frozen. */
 
@@ -1714,21 +1723,29 @@ fl_hide_object( FL_OBJECT * obj )
  * '^#' stand for '#'
  * '^&' stand for '&'
  * Note: '&' followed by anything else than the above will be skipped,
- * e.g. '&E' or '&0'. If '&' is followed by a number larger than 34
+ * e.g. '&E' or '&0'. If '&' is followed by a number larger than 35
  * only the first digit of the number is used.
  * Not escapable are Crtl-^, Crtl-# and Ctrl-&.
+ * No non-ASCII UTF-8 characters are allowed.
  ***************************************/
 
-#include <ctype.h>
-
 int
 fli_convert_shortcut( const char * str,
-                      long       * sc )
+                      FL_VAL     * sc )
 {
     int i = 0;
     long offset = 0;
     const char *c;
 
+    if ( utf8_length( str ) != ( ssize_t ) strlen( str ) )
+    {
+        M_err( "fli_convert_shortcut",
+               "Shortcuts may only contain ASCII characters" );
+        
+        sc[ 0 ] = 0;
+        return 0;
+    }
+
     for ( c = str; *c && i < MAX_SHORTCUTS; c++ )
     {
         switch ( *c )
@@ -1873,8 +1890,8 @@ fl_set_object_shortcut( FL_OBJECT  * obj,
 {
     int scsize,
         n;
-    long sc[ MAX_SHORTCUTS + 1 ];      /* converted shortcuts - we need one
-                                          more than max for trailing 0 */
+    FL_VAL sc[ MAX_SHORTCUTS + 1 ];   /* converted shortcuts - we need one
+                                         more than max for trailing 0 */
 
     if ( ! obj )
     {
@@ -1888,7 +1905,8 @@ fl_set_object_shortcut( FL_OBJECT  * obj,
         return;
     }
 
-    n = fli_convert_shortcut( sstr, sc );
+    if ( ( n = fli_convert_shortcut( sstr, sc ) ) == 0 )
+        return;
     scsize = ( n + 1 ) * sizeof *obj->shortcut;
     obj->shortcut = fl_realloc( obj->shortcut, scsize );
     memcpy( obj->shortcut, sc, scsize );
@@ -1918,8 +1936,8 @@ fl_set_object_shortcut( FL_OBJECT  * obj,
  ***************************************/
 
 void
-fl_set_object_shortcutkey( FL_OBJECT    * obj,
-                           unsigned int   keysym )
+fl_set_object_shortcutkey( FL_OBJECT * obj,
+                           FL_VAL      keysym )
 {
     size_t n;
 
@@ -1936,7 +1954,7 @@ fl_set_object_shortcutkey( FL_OBJECT    * obj,
 
 
 /***************************************
- * Sets the object in the form that gets keyboard input.
++ * Sets the object in the form that gets keyboard input.
  ***************************************/
 
 void
@@ -1983,7 +2001,7 @@ fl_get_focus_object( FL_FORM * form )
 
 /***************************************
  * Returns an object of type 'find' in a form, starting at 'obj'.
- * If find_object() does not return an object the event that
+ * If the function does not return an object the event that
  * triggered the call will be eaten. This is how the deactived
  * and inactive objects reject events.
  * Modify with care!
@@ -1992,11 +2010,10 @@ fl_get_focus_object( FL_FORM * form )
 FL_OBJECT *
 fli_find_object( FL_OBJECT * obj,
                  int         find,
-                 FL_Coord    mx,
-                 FL_Coord    my )
+                 FL_COORD    mx,
+                 FL_COORD    my )
 {
-    while ( obj )
-    {
+    for ( ; obj; obj = obj->next )
         if (    obj->objclass != FL_BEGIN_GROUP
              && obj->objclass != FL_END_GROUP
              && obj->visible
@@ -2024,9 +2041,6 @@ fli_find_object( FL_OBJECT * obj,
                 return obj;
         }
 
-        obj = obj->next;
-    }
-
     return NULL;
 }
 
@@ -2038,8 +2052,8 @@ fli_find_object( FL_OBJECT * obj,
 FL_OBJECT *
 fli_find_object_backwards( FL_OBJECT * obj,
                            int         find,
-                           FL_Coord    mx,
-                           FL_Coord    my )
+                           FL_COORD    mx,
+                           FL_COORD    my )
 {
     for ( ; obj; obj = obj->prev )
         if (    obj->objclass != FL_BEGIN_GROUP
@@ -2077,22 +2091,22 @@ fli_find_object_backwards( FL_OBJECT * obj,
 FL_OBJECT *
 fli_find_first( FL_FORM  * form,
                 int        find,
-                FL_Coord   mx,
-                FL_Coord   my )
+                FL_COORD   mx,
+                FL_COORD   my )
 {
     return fli_find_object( form->first, find, mx, my );
 }
 
 
 /***************************************
- * Returns the last object of the type find
+ * Returns the last object of type 'find'
  ***************************************/
 
 FL_OBJECT *
 fli_find_last( FL_FORM * form,
                int       find,
-               FL_Coord  mx,
-               FL_Coord  my )
+               FL_COORD  mx,
+               FL_COORD  my )
 {
     FL_OBJECT *last,
               *obj;
@@ -2115,20 +2129,20 @@ fli_find_last( FL_FORM * form,
 
 
 /***************************************
+ * Returns if an object only parially or not at all visible due to clipping
  ***************************************/
 
 static int
 is_object_clipped( FL_OBJECT * obj )
 {
-    FL_RECT obj_rect,
-            *xc;
+    FL_RECT * xc;
 
     if ( ! fl_is_global_clipped( ) )
         return 0;
 
-    get_object_rect( obj, &obj_rect, 1 );
+    fli_calc_object_bbox( obj );
 
-    xc = fli_intersect_rects( &obj_rect, fli_get_global_clip_rect( ) );
+    xc = fli_intersect_rects( &obj->bbox, fli_get_global_clip_rect( ) );
 
     if ( ! xc )
         return 1;
@@ -2169,7 +2183,7 @@ mark_object_for_redraw( FL_OBJECT * obj )
 
     /* If an object is marked as being under another object we have to find
        the object(s) it is beneath and also mark them for a redraw. For the
-       special case that the object to be redraw is the first object of
+       special case that the object to be redrawn is the first object of
        the form (i.e. the one for the background) we don't have to check
        if the other object are on top of it, they all are. */
 
@@ -2191,7 +2205,6 @@ mark_object_for_redraw( FL_OBJECT * obj )
         /* If it hasn't been done yet pre-calculate the sizes of all
            objects possibly concerned */
 
-        int need_finish = prep_recalc( obj->form, obj );
         int cnt = 0;
 
         for ( o = obj->next; o; o = o->next )
@@ -2214,9 +2227,6 @@ mark_object_for_redraw( FL_OBJECT * obj )
                     break;
             }
         }
-
-        if ( need_finish )
-            finish_recalc( obj->form, obj );
     }
 }
 
@@ -2244,13 +2254,8 @@ fl_redraw_object( FL_OBJECT * obj )
         /* If it hasn't been done yet pre-calculate the sizes of all
             objects possibly concerned */
 
-        int need_finish = prep_recalc( o->form, o );
-
         for ( ; o && o->objclass != FL_END_GROUP; o = o->next )
             mark_object_for_redraw( o );
-
-        if ( need_finish )
-            finish_recalc( obj->form, obj->next ); 
     }
     else
         mark_object_for_redraw( obj );
@@ -2265,32 +2270,13 @@ fl_redraw_object( FL_OBJECT * obj )
  ***************************************/
 
 static int
-objects_intersect( FL_OBJECT * obj1,
-                   FL_OBJECT * obj2 )
+objects_intersect( const FL_OBJECT * obj1,
+                   const FL_OBJECT * obj2 )
 {
-    if ( tmp_vdata )
-    {
-        FL_RECT *r1 = obj1->u_vdata,
-                *r2 = obj2->u_vdata;
-
-        return    r1->x + r1->width  > r2->x
-               && r2->x + r2->width  > r1->x
-               && r1->y + r1->height > r2->y
-               && r2->y + r2->height > r1->y;
-
-    }
-    else
-    {
-        FL_RECT r1, r2;
-
-        get_object_rect( obj1, &r1, 0 );
-        get_object_rect( obj2, &r2, 0 );
-
-        return    r1.x + r1.width  > r2.x
-               && r2.x + r2.width  > r2.x
-               && r1.y + r1.height > r2.y
-               && r2.y + r2.height > r1.y;
-    }
+    return    obj1->bbox.x + obj1->bbox.width  > obj2->bbox.x
+           && obj2->bbox.x + obj2->bbox.width  > obj1->bbox.x
+           && obj1->bbox.y + obj1->bbox.height > obj2->bbox.y
+           && obj2->bbox.y + obj2->bbox.height > obj1->bbox.y;
 }
 
 
@@ -2326,7 +2312,7 @@ redraw( FL_FORM * form,
     /* Set the window (or drawable) to be drawn and, if necessary, set up
        a pixmap for the form */
 
-    fli_set_form_window( form );
+    fl_winset( form->window );
     fli_create_form_pixmap( form );
 
     for ( obj = bg_object( form ); obj; obj = obj->next )
@@ -2385,13 +2371,12 @@ redraw( FL_FORM * form,
 
 
 /***************************************
- * Exported function for drawing a form
+ * Exported function for redrawing a form
  ***************************************/
 
 void
 fl_redraw_form( FL_FORM * form )
 {
-    fli_recalc_intersections( form );
     redraw( form, 1 );
 }
 
@@ -2432,14 +2417,10 @@ fl_unfreeze_form( FL_FORM * form )
         return;
     }
 
-    /* If the form becomes unfrozen at last and is visible recalculate
-       overlaps between the objects and then redraw all objects that have
-       been marked for a redraw since it became frozen or, if some objects
-       became hidden during that time, all objects. */
+    /* If the form becomes unfrozen redraw all objects marked for a redraw */
 
     if ( --form->frozen == 0 && form->visible == FL_VISIBLE )
     {
-        fli_recalc_intersections( form );
         redraw( form, form->in_redraw & HIDE_WHILE_FROZEN );
         form->in_redraw &= ~ HIDE_WHILE_FROZEN;
     }
@@ -2552,8 +2533,8 @@ void unconditional_hide_tooltip( FL_OBJECT * obj )
 static int
 handle_object( FL_OBJECT * obj,
                int         event,
-               FL_Coord    mx,
-               FL_Coord    my,
+               FL_COORD    mx,
+               FL_COORD    my,
                int         key,
                XEvent    * xev,
                int         keep_ret )
@@ -2561,7 +2542,7 @@ handle_object( FL_OBJECT * obj,
     static unsigned long last_clicktime = 0;
     static int last_dblclick = 0,
                last_key = 0;
-    static FL_Coord last_mx,
+    static FL_COORD last_mx,
                     last_my;
     int cur_event;
     FL_OBJECT *p;
@@ -2660,7 +2641,7 @@ handle_object( FL_OBJECT * obj,
         case FL_FOCUS:
             /* 'refocus' is set if on the last FL_UNFOCUS it was found
                that the text in the input field didn't validate. In that
-               case the focus has to go back to that field instead to a
+               case the focus has to go back to that field and *not* to a
                different one */
 
             if ( refocus && refocus->form )
@@ -2747,9 +2728,9 @@ handle_object( FL_OBJECT * obj,
 void
 fli_handle_object( FL_OBJECT * obj,
                    int         event,
-                   FL_Coord    mx,
-                   FL_Coord    my,
-                   int         key,
+                   FL_COORD    mx,
+                   FL_COORD    my,
+                   FL_VAL      key,
                    XEvent    * xev,
                    int         enter_it )
 {
@@ -2757,17 +2738,15 @@ fli_handle_object( FL_OBJECT * obj,
         return;
 
     /* If 'enter_it' is set the object is inserted into the object queue and
-       it's 'returned' member is modified. If not, just the handler for
+       its 'returned' member is modified. If not, just the handler for
        the object is called, but it doesn't appear in the queue and the
        'returned' member remains unmodified. Also don't enter the object
-       into the queue if it's form doesn't exist or the forms window isn't
+       into the queue if its form doesn't exist or the forms window isn't
        mapped. */
 
     if ( enter_it && obj->form && obj->form->window )
     {
-        int res;
-
-        if ( ( res = handle_object( obj, event, mx, my, key, xev, 0 ) ) )
+        if ( handle_object( obj, event, mx, my, key, xev, 0 ) )
             fli_object_qenter( obj, event );
     }
     else
@@ -2779,12 +2758,12 @@ fli_handle_object( FL_OBJECT * obj,
  * Sets the callback routine for the object
  ***************************************/
 
-FL_CALLBACKPTR
-fl_set_object_callback( FL_OBJECT      * obj,
-                        FL_CALLBACKPTR   callback,
-                        long             argument )
+FL_CALLBACK_PTR
+fl_set_object_callback( FL_OBJECT       * obj,
+                        FL_CALLBACK_PTR   callback,
+                        long              argument )
 {
-    FL_CALLBACKPTR old;
+    FL_CALLBACK_PTR old;
 
     if ( ! obj )
     {
@@ -2855,6 +2834,7 @@ fl_set_object_bw( FL_OBJECT * obj,
             if ( obj->bw != bw )
             {
                 obj->bw = bw;
+                fli_calc_object_bbox( obj );
                 fli_handle_object( obj, FL_ATTRIB, 0, 0, 0, NULL, 0 );
                 mark_object_for_redraw( obj );
             }
@@ -2865,6 +2845,7 @@ fl_set_object_bw( FL_OBJECT * obj,
     else if ( obj->bw != bw && obj->objclass != FL_TABFOLDER )
     {
         obj->bw = bw;
+        fli_calc_object_bbox( obj );
         fli_handle_object( obj, FL_ATTRIB, 0, 0, 0, NULL, 0 );
 
         if ( obj->objclass == FL_TABFOLDER )
@@ -2997,14 +2978,15 @@ fli_scale_object( FL_OBJECT * obj,
 
         obj->fl2  = obj->fl1 + new_w;
         obj->fr2  = obj->form->w_hr - obj->fl2;
-        obj->ft2  = obj->ft1 + new_h;;
-        obj->fb2  = obj->form->h_hr - obj->ft2;;
+        obj->ft2  = obj->ft1 + new_h;
+        obj->fb2  = obj->form->h_hr - obj->ft2;
 
         obj->x    = FL_crnd( obj->fl1 );
         obj->y    = FL_crnd( obj->ft1 );
         obj->w    = FL_crnd( new_w );
         obj->h    = FL_crnd( new_h );
 
+        fli_calc_object_bbox( obj );
         fli_handle_object( obj, FL_RESIZED, 0, 0, 0, NULL, 0 );
 
         /* If there are child objects also inform them about the size change */
@@ -3019,11 +3001,11 @@ fli_scale_object( FL_OBJECT * obj,
  * Register a preemptive object handler
  ***************************************/
 
-FL_HANDLEPTR
-fl_set_object_prehandler( FL_OBJECT    * obj,
-                          FL_HANDLEPTR   phandler )
+FL_HANDLE_PTR
+fl_set_object_prehandler( FL_OBJECT     * obj,
+                          FL_HANDLE_PTR   phandler )
 {
-    FL_HANDLEPTR oldh = obj->prehandle;
+    FL_HANDLE_PTR oldh = obj->prehandle;
 
     obj->prehandle = phandler;
     return oldh;
@@ -3033,11 +3015,11 @@ fl_set_object_prehandler( FL_OBJECT    * obj,
 /***************************************
  ***************************************/
 
-FL_HANDLEPTR
-fl_set_object_posthandler( FL_OBJECT    * obj,
-                           FL_HANDLEPTR   post )
+FL_HANDLE_PTR
+fl_set_object_posthandler( FL_OBJECT     * obj,
+                           FL_HANDLE_PTR   post )
 {
-    FL_HANDLEPTR oldh = obj->posthandle;
+    FL_HANDLE_PTR oldh = obj->posthandle;
 
     obj->posthandle = post;
     return oldh;
@@ -3089,8 +3071,13 @@ fl_draw_object_label( FL_OBJECT * obj )
         fl_draw_text( align, obj->x, obj->y, obj->w, obj->h,
                       obj->lcol, obj->lstyle, obj->lsize, obj->label );
     else
+    {
+#if FL_ENABLE_XFT
+        fli_bk_textcolor( fl_get_form_background_color( obj->form ) );
+#endif
         fl_draw_text_beside( align, obj->x, obj->y, obj->w, obj->h,
                              obj->lcol, obj->lstyle, obj->lsize, obj->label );
+    }
 }
 
 
@@ -3100,6 +3087,12 @@ fl_draw_object_label( FL_OBJECT * obj )
 void
 fl_draw_object_label_outside( FL_OBJECT * obj )
 {
+    if ( ! obj->label || ! *obj->label )
+        return;
+
+#if FL_ENABLE_XFT
+    fli_bk_textcolor( fl_get_form_background_color( obj->form ) );
+#endif
     fl_draw_text_beside( fl_to_outside_lalign( obj->align ),
                          obj->x, obj->y, obj->w, obj->h,
                          obj->lcol, obj->lstyle, obj->lsize, obj->label );
@@ -3133,7 +3126,7 @@ fl_call_object_callback( FL_OBJECT * obj )
  ***************************************/
 
 static int
-object_is_under( FL_OBJECT * obj )
+object_is_under( const FL_OBJECT * obj )
 {
     FL_OBJECT *o;
     int cnt = 0;
@@ -3163,92 +3156,6 @@ object_is_under( FL_OBJECT * obj )
 }
 
 
-/***************************************
- * Helper function for fli_recalc_intersections() and other functions -
- * without this is a O(N^2) operation with respect to the recalculations
- * of the N object bounding boxes. Here we use that the 'u_vdata' pointers
- * of the objects don't get used during fli_recalc_intersections() and
- * replace them all by pointers to pre-calculated bounding boxes, thus
- * reducing the number of recalculations to N (in objects_intersect() it
- * gets checked if 'tmp_vdata' is non-NULL and then uses the pre-calculated
- * bounding boxes).
- ***************************************/
-
-static int
-prep_recalc( FL_FORM   * form,
-             FL_OBJECT * start_obj )
-{
-    FL_OBJECT *obj;
-    int cnt = 0;
-    int i = 0;
-
-    if ( ! form || tmp_vdata )
-        return 0;
-
-    if ( ! start_obj )
-        start_obj = bg_object( form );
-
-    /* Count how many objects the form contains */
-
-    for ( obj = start_obj; obj; obj = obj->next )
-        cnt++;
-
-    if ( cnt < 2 )
-        return 0;
-
-    /* Get memory for temporary storing the 'u_vdata' pointers of all objects
-       and as many FL_RECT's */
-
-    if ( ( tmp_vdata = fl_malloc( cnt * sizeof *tmp_vdata ) ) )
-    {
-        if ( ! ( tmp_rects = fl_malloc( cnt * sizeof *tmp_rects ) ) )
-        {
-            fli_safe_free( tmp_vdata );
-            return 0;
-        }
-    }
-    else
-        return 0;
-
-    /* Save the 'u_vdata' pointers and replace them by pointers to the
-       bounding box rectangles */
-
-    for ( obj = start_obj; obj; obj = obj->next )
-    {
-        tmp_vdata[ i ] = obj->u_vdata;
-        obj->u_vdata = tmp_rects + i;
-        get_object_rect( obj, tmp_rects + i++, 0 );
-    }
-
-    return 1;
-}
-
-
-/***************************************
- * Another helper function for fli_recalc_intersections() - to be called when
- * it's finished, restoring all objects 'u_vdata' pointers and getting rid
- * of allocated memory.
- ***************************************/
-
-static void
-finish_recalc( FL_FORM   * form,
-               FL_OBJECT * start_obj )
-{
-    FL_OBJECT *obj;
-    int i = 0;
-
-    if ( ! tmp_vdata )
-        return;
-
-    for ( obj = start_obj ? start_obj : bg_object( form ); obj;
-          obj = obj->next )
-        obj->u_vdata = tmp_vdata[ i++ ];
-
-    fli_safe_free( tmp_rects );
-    fli_safe_free( tmp_vdata );
-}
-   
-
 /***************************************
  * Rechecks for all objects of a form if they are
  * partially or fully hidden by another object
@@ -3269,10 +3176,8 @@ fli_recalc_intersections( FL_FORM * form )
     if ( fl_current_form || ! form || ( form && form->frozen ) )
         return;
 
-    prep_recalc( form, NULL );
     for ( obj = bg_object( form ); obj && obj->next; obj = obj->next )
         obj->is_under = object_is_under( obj );
-    finish_recalc( form, NULL );
 }
 
 
@@ -3281,10 +3186,10 @@ fli_recalc_intersections( FL_FORM * form )
 
 void
 fl_move_object( FL_OBJECT * obj,
-                FL_Coord    dx,
-                FL_Coord    dy )
+                FL_COORD    dx,
+                FL_COORD    dy )
 {
-     FL_Coord x,
+     FL_COORD x,
               y;
      if ( fli_inverted_y )
          dy = - dy;
@@ -3320,8 +3225,8 @@ fl_move_object( FL_OBJECT * obj,
 
 void
 fl_get_object_position( FL_OBJECT * obj,
-                        FL_Coord  * x,
-                        FL_Coord  * y )
+                        FL_COORD  * x,
+                        FL_COORD  * y )
 {
     *x = obj->x;
     *y = fli_inverted_y ? TRANSLATE_Y( obj, obj->form ) : obj->y;
@@ -3334,8 +3239,8 @@ fl_get_object_position( FL_OBJECT * obj,
 
 void
 fl_set_object_position( FL_OBJECT * obj,
-                        FL_Coord    x,
-                        FL_Coord    y )
+                        FL_COORD    x,
+                        FL_COORD    y )
 {
     int need_show = 0;
     double diff;
@@ -3374,6 +3279,7 @@ fl_set_object_position( FL_OBJECT * obj,
         obj->y = y;
     }
 
+    fli_calc_object_bbox( obj );
     fli_handle_object( obj, FL_MOVEORIGIN, 0, 0, 0, NULL, 0 );
 
     if ( need_show )
@@ -3387,8 +3293,8 @@ fl_set_object_position( FL_OBJECT * obj,
 
 void
 fl_get_object_size( FL_OBJECT * obj,
-                    FL_Coord  * w,
-                    FL_Coord  * h )
+                    FL_COORD  * w,
+                    FL_COORD  * h )
 {
     *w = obj->w;
     *h = obj->h;
@@ -3401,8 +3307,8 @@ fl_get_object_size( FL_OBJECT * obj,
 
 void
 fl_set_object_size( FL_OBJECT * obj,
-                    FL_Coord    w,
-                    FL_Coord    h )
+                    FL_COORD    w,
+                    FL_COORD    h )
 {
     int need_show = 0;
     double diff;
@@ -3470,6 +3376,7 @@ fl_set_object_size( FL_OBJECT * obj,
         obj->h = FL_crnd( obj->ft2 - obj->ft1 );
     }
 
+    fli_calc_object_bbox( obj );
     fli_handle_object( obj, FL_RESIZED, 0, 0, 0, NULL, 0 );
 
     /* If there are child objects also inform them about the size change */
@@ -3488,10 +3395,10 @@ fl_set_object_size( FL_OBJECT * obj,
 
 void
 fl_get_object_geometry( FL_OBJECT * obj,
-                        FL_Coord  * x,
-                        FL_Coord  * y,
-                        FL_Coord  * w,
-                        FL_Coord  * h )
+                        FL_COORD  * x,
+                        FL_COORD  * y,
+                        FL_COORD  * w,
+                        FL_COORD  * h )
 {
     fl_get_object_position( obj, x, y );
     fl_get_object_size( obj, w, h );
@@ -3504,10 +3411,10 @@ fl_get_object_geometry( FL_OBJECT * obj,
 
 void
 fl_set_object_geometry( FL_OBJECT * obj,
-                        FL_Coord    x,
-                        FL_Coord    y,
-                        FL_Coord    w,
-                        FL_Coord    h )
+                        FL_COORD    x,
+                        FL_COORD    y,
+                        FL_COORD    w,
+                        FL_COORD    h )
 {
     fl_set_object_size( obj, w, h );
     fl_set_object_position( obj, x, y );
@@ -3520,22 +3427,20 @@ fl_set_object_geometry( FL_OBJECT * obj,
 
 void
 fl_get_object_bbox( FL_OBJECT * obj,
-                    FL_Coord  * x,
-                    FL_Coord  * y,
-                    FL_Coord  * w,
-                    FL_Coord  * h )
+                    FL_COORD  * x,
+                    FL_COORD  * y,
+                    FL_COORD  * w,
+                    FL_COORD  * h )
 {
-    XRectangle rect;
+    fli_calc_object_bbox( obj );
 
-    get_object_rect( obj, &rect, 0 );
-
-    *x = rect.x;
+    *x = obj->bbox.x;
     if ( ! fli_inverted_y || ! obj->form )
-        *y = rect.y;
+        *y = obj->bbox.y;
     else
-        *y = obj->form->h - rect.height - rect.y;
-    *w = rect.width;
-    *h = rect.height;
+        *y = obj->form->h - obj->bbox.height - obj->bbox.y;
+    *w = obj->bbox.width;
+    *h = obj->bbox.height;
 }
 
 
@@ -3543,8 +3448,8 @@ fl_get_object_bbox( FL_OBJECT * obj,
  ***************************************/
 
 static XRectangle *
-get_label_rect( FL_OBJECT  * obj,
-                XRectangle * rect )
+get_label_rect( const FL_OBJECT * obj,
+                XRectangle      * rect )
 {
     int sw,
         sh;
@@ -3596,11 +3501,11 @@ get_label_rect( FL_OBJECT  * obj,
  * Returns the area covered by the object and its label via a FL_RECT
  ***************************************/
 
-static void
-get_object_rect( FL_OBJECT * obj,
-                 FL_RECT   * rect,
-                 int         extra )
+void
+fli_calc_object_bbox( FL_OBJECT * obj )
 {
+    int extra = 0;
+
     if (    obj->objclass == FL_FRAME
          || obj->objclass == FL_LABELFRAME
          || obj->objclass == FL_CANVAS
@@ -3609,20 +3514,16 @@ get_object_rect( FL_OBJECT * obj,
               && obj->objclass <= FL_USER_CLASS_END ) )
         extra += FL_abs( obj->bw );
 
-    rect->x      = obj->x - extra;
-    rect->y      = obj->y - extra;
-    rect->width  = obj->w + 2 * extra + 1;
-    rect->height = obj->h + 2 * extra + 1;
-
-    /* Include the label into the box - but only for labels that are not
-       within the object. If "inside" labels extend beyond the limits of the
-       object things look ugly anyway and it doesn't seem to make too much
-       sense to slow down the program any further for that case. */
+    obj->bbox.x      = obj->x - extra;
+    obj->bbox.y      = obj->y - extra;
+    obj->bbox.width  = obj->w + 2 * extra;
+    obj->bbox.height = obj->h + 2 * extra;
 
     if ( obj->label && *obj->label && OL( obj ) )
     {
-        XRectangle lr;
-        fli_combine_rectangles( rect, get_label_rect( obj, &lr ) );
+        FL_RECT lr;
+
+        fli_combine_rectangles( &obj->bbox, get_label_rect( obj, &lr ) );
     }
 }
 
@@ -3634,20 +3535,22 @@ void
 fl_set_object_automatic( FL_OBJECT * obj,
                          int         flag )
 {
-    if ( obj->automatic != ( flag ? 1 : 0 ) )
+    flag = flag ? 1 : 0;
+
+    if ( obj->automatic == flag )
+        return;
+
+    obj->automatic = flag;
+
+    if ( obj->form )
     {
-        obj->automatic = flag ? 1 : 0;
-
-        if ( obj->form )
-        {
-            if ( flag )
-                obj->form->num_auto_objects++;
-            else
-                obj->form->num_auto_objects--;
-        }
-
-        fli_recount_auto_objects( );
+        if ( flag )
+            obj->form->num_auto_objects++;
+        else
+            obj->form->num_auto_objects--;
     }
+
+    fli_recount_auto_objects( );
 }
 
 
@@ -3698,12 +3601,16 @@ lose_focus( FL_OBJECT * obj )
 
 
 /***************************************
- * Part of the public interface, not used within the library
+ * Part of the public interface, not used within the library.
+ * Calls a user supplied function on all objects of a form but stops
+ * in between of the function, when called on one of the objects,
+ * returns 0. The function also gets called for objects that mark the
+ * begin and end of a group!
  ***************************************/
 
 void
 fl_for_all_objects( FL_FORM * form,
-                    int       ( * cb )( FL_OBJECT *, void * ),
+                    int       ( * fp )( FL_OBJECT *, void * ),
                     void    * v )
 {
     FL_OBJECT *obj;
@@ -3714,13 +3621,13 @@ fl_for_all_objects( FL_FORM * form,
         return;
     }
 
-    if ( ! cb )
+    if ( ! fp )
     {
         M_err( "fl_for_all_objects", "NULL callback function" );
         return;
     }
 
-    for ( obj = bg_object( form ); obj && ! cb( obj, v ); obj = obj->next )
+    for ( obj = bg_object( form ); obj && ! fp( obj, v ); obj = obj->next )
         /* empty */ ;
 }
 
@@ -3762,10 +3669,10 @@ fl_set_object_helper_f( FL_OBJECT  * obj,
 /***************************************
  * Function for setting the conditions under which an object gets
  * returned (or its callback invoked). If the object has to do
- * additional work on setting te condition (e.g. it has child
- * objects that also need to be set) it has to set up it's own
- * function that then will called in the end. This function should
- * only be called once an object has been created completely!
+ * additional work on setting the condition (e.g. it has child
+ * objects that also need to be set) it has to set up its own
+ * function that then will be called in the end. This function should
+ * only be called once an object has been fully created!
  ***************************************/
 
 int
@@ -3821,6 +3728,8 @@ void
 fli_set_object_visibility( FL_OBJECT * obj,
                            int         vis )
 {
+    vis = vis ? 1 : 0;
+
     if ( obj )        /* let's be careful... */
     {
         obj->visible = vis;
@@ -3836,9 +3745,9 @@ fli_set_object_visibility( FL_OBJECT * obj,
  ***************************************/
 
 int
-fli_mouse_wheel_to_keypress( int  * ev,
-                             int  * key,
-                             void * xev )
+fli_mouse_wheel_to_keypress( int     * ev,
+                             FL_VAL  * key,
+                             void    * xev )
 {
     if ( ! (    *ev == FL_RELEASE
              && ( *key == FL_MBUTTON4 || *key == FL_MBUTTON5 ) ) )
@@ -3869,6 +3778,46 @@ fli_mouse_wheel_to_keypress( int  * ev,
 }
 
 
+/***************************************
+ * Function allows to set up to which mouse
+ * buttons the object will react to.
+ ***************************************/
+
+unsigned int
+fl_set_object_mouse_buttons( FL_OBJECT    * obj,
+                             unsigned int   mouse_buttons )
+{
+    if ( ! obj )
+    {
+        M_err( "fl_set_object_mouse_buttons", "NULL object" );
+        return 0;
+    }
+
+    if ( obj->set_react_to )
+        return obj->set_react_to( obj, mouse_buttons );
+
+    return obj->react_to = mouse_buttons & 0x1F;
+}
+
+
+/***************************************
+ * Function returns value indicating which mouse buttons
+ * the object reacts to.
+ ***************************************/
+
+unsigned int
+fl_get_object_mouse_buttons( FL_OBJECT * obj )
+{
+    if ( ! obj )
+    {
+        M_err( "fl_get_object_mouse_buttons", "NULL object" );
+        return 0;
+    }
+
+    return obj->react_to;
+}
+
+
 /*
  * Local variables:
  * tab-width: 4
